@@ -53,7 +53,7 @@ class CircularEquilibrium(Equilibrium):
                 "Coefficients determining the safety factor q. Value is a float "
                 "(treated as a length-0 sequence) or a sequence of floats. The values "
                 "a[i] are used as the coefficients of a polynomial series "
-                "q(r) = a[0] + a[1]*r + a[2]*r**2 + ..."
+                "q(r) = a[0] + a[1]*r**2 + a[2]*r**4 + ..."
             ),
             value_type=(float, Sequence),
             check_all=lambda x: all(is_positive(y) for y in tuple(x)),
@@ -211,7 +211,7 @@ class CircularEquilibrium(Equilibrium):
         r = sqrt((R - R0)**2 + Z**2)
         """
         R0 = self.user_options.R0
-        return np.sqrt((R - R0) ** 2 + Z ** 2)
+        return np.sqrt((R - R0) ** 2 + Z**2)
 
     def theta(self, R, Z):
         """
@@ -226,10 +226,10 @@ class CircularEquilibrium(Equilibrium):
         """
         if not hasattr(self, "_q"):
             coef_list = self.user_options.q_coefficients
-            exponent_list = range(len(coef_list))
+            exponent_list = range(0, 2 * len(coef_list), 2)
 
             def func(x):
-                return sum(c * x ** e for c, e in zip(coef_list, exponent_list))
+                return sum(c * x**e for c, e in zip(coef_list, exponent_list))
 
             self._q = func
 
@@ -249,7 +249,7 @@ class CircularEquilibrium(Equilibrium):
                 self._dqdr = func
             else:
                 coef_list = coef_list[1:]
-                exponent_list = range(1, len(coef_list) + 1)
+                exponent_list = range(1, 2 * len(coef_list) + 1, 2)
 
                 def func(x):
                     return sum(
@@ -269,7 +269,7 @@ class CircularEquilibrium(Equilibrium):
             R0 = self.user_options.R0
 
             def func(x):
-                return B0 * x / (np.sqrt(1.0 - x ** 2 / R0 ** 2) * self.q(x))
+                return B0 * x / (np.sqrt(1.0 - x**2 / R0**2) * self.q(x))
 
             self._dpsidr_r = func
 
@@ -290,14 +290,14 @@ class CircularEquilibrium(Equilibrium):
 
             def func(x):
                 return (
-                    B0 / (np.sqrt(1.0 - x ** 2 / R0 ** 2) * self.q(x))
+                    B0 / (np.sqrt(1.0 - x**2 / R0**2) * self.q(x))
                     + B0
-                    * x ** 2
-                    / (R0 ** 2 * (1.0 - x ** 2 / R0 ** 2) ** 1.5 * self.q(x))
+                    * x**2
+                    / (R0**2 * (1.0 - x**2 / R0**2) ** 1.5 * self.q(x))
                     - B0
                     * x
                     * self.dqdr(x)
-                    / (np.sqrt(1.0 - x ** 2 / R0 ** 2) * self.q(x) ** 2)
+                    / (np.sqrt(1.0 - x**2 / R0**2) * self.q(x) ** 2)
                 )
 
             self._d2psidr2_r = func
@@ -312,7 +312,9 @@ class CircularEquilibrium(Equilibrium):
         above eq (24) in Jolliet et al.
 
         Integrals done with Wolfram Alpha for the first few values of the maximum order
-        in the polynomial q(r) = a0 + a1 * r + a2 * r**2 + ...
+        in the polynomial q(r) = a0 + a1 * r**2 + a2 * r**4 + ...
+        where only even powers of r are used so that q(r) is even at r=0 so there is no
+        discontinuity in gradient at the magnetic axis.
         """
         if not hasattr(self, "_psi_r"):
             coef_array = np.array(self.user_options.q_coefficients)
@@ -323,9 +325,9 @@ class CircularEquilibrium(Equilibrium):
                 def func(x):
                     return (
                         B0
-                        * R0 ** 2
+                        * R0**2
                         / coef_array[0]
-                        * (1.0 - np.sqrt(1.0 - x ** 2 / R0 ** 2))
+                        * (1.0 - np.sqrt(1.0 - x**2 / R0**2))
                     )
 
                 self._psi_r = func
@@ -336,92 +338,35 @@ class CircularEquilibrium(Equilibrium):
                     return (
                         B0
                         * R0
-                        / a1
-                        * (
-                            np.arctan(x / np.sqrt(R0 ** 2 - x ** 2))
-                            - a0
-                            * np.arctan(
-                                (a0 * x + a1 * R0 ** 2)
-                                / np.sqrt(
-                                    (R0 ** 2 - x ** 2) * (a0 ** 2 - a1 ** 2 * R0 ** 2)
-                                )
-                            )
-                            / np.sqrt(a0 ** 2 - a1 ** 2 * R0 ** 2)
-                        )
-                    )
-
-                self._psi_r = func
-            elif len(coef_array) == 3:
-                raise ValueError(
-                    "This expression needs careful checking before being used - it's "
-                    "so long that the chance of typos is high!"
-                )
-                a0, a1, a2 = coef_array
-
-                def func(x):
-                    return (
-                        np.sqrt(2.0 / (a1 ** 2 - 4.0 * a0 * a2))
-                        * B0
-                        * R0
-                        * (
+                        * np.log(
                             (
-                                (np.sqrt(a1 ** 2 - 4.0 * a0 * a2) + a1)
-                                * np.arctan(
-                                    (
-                                        x * np.sqrt(a1 ** 2 - 4.0 * a0 * a2)
-                                        + a1 * x
-                                        + 2.0 * a2 * R0 ** 2
-                                    )
-                                    / (
-                                        np.sqrt(2.0 * (R0 ** 2 - x ** 2))
-                                        * np.sqrt(
-                                            a1 * np.sqrt(a1 ** 2 - 4.0 * a0 * a2)
-                                            - 2.0 * a2 * (a0 + a2 * R0 ** 2)
-                                            + a1 ** 2
-                                        )
+                                (1.0 + R0 * np.sqrt(a1 / (a0 + a1 * R0**2)))
+                                * (
+                                    -1.0
+                                    + np.sqrt(
+                                        (a1 * (-(x**2) + R0**2))
+                                        / (a0 + a1 * R0**2)
                                     )
                                 )
                             )
                             / (
-                                2.0
-                                * np.sqrt(
-                                    a1 * np.sqrt(a1 ** 2 - 4.0 * a0 * a2)
-                                    - 2.0 * a2 * (a0 + a2 * R0 ** 2)
-                                    + a1 ** 2
-                                )
-                            )
-                            - (
-                                (np.sqrt(a1 ** 2 - 4.0 * a0 * a2) - a1)
-                                * np.sqrt(
-                                    -a1 * np.sqrt(a1 ** 2 - 4.0 * a0 * a2)
-                                    - 2.0 * a2 * (a0 + a2 * R0 ** 2)
-                                    + a1 ** 2
-                                )
-                                * np.arctan(
-                                    (
-                                        -x * np.sqrt(a1 ** 2 - 4.0 * a0 * a2)
-                                        + a1 * x
-                                        + 2.0 * a2 * R0 ** 2
-                                    )
-                                    / (
-                                        np.sqrt(2.0 * (R0 ** 2 - x ** 2))
-                                        * np.sqrt(
-                                            -a1 * np.sqrt(a1 ** 2 - 4.0 * a0 * a2)
-                                            - 2.0 * a2 * (a0 + a2 * R0 ** 2)
-                                            + a1 ** 2
-                                        )
+                                (-1.0 + R0 * np.sqrt(a1 / (a0 + a1 * R0**2)))
+                                * (
+                                    1.0
+                                    + np.sqrt(
+                                        (a1 * (-(x**2) + R0**2))
+                                        / (a0 + a1 * R0**2)
                                     )
                                 )
                             )
-                            / (
-                                2.0 * a1 * np.sqrt(a1 ** 2 - 4.0 * a0 * a2)
-                                + 4.0 * a2 * (a0 + a2 * R0 ** 2)
-                                - 2.0 * a1 ** 2
-                            )
                         )
+                        / (2.0 * np.sqrt(a1 * (a0 + a1 * R0**2)))
                     )
 
                 self._psi_r = func
+            # Note, don't seem to be able to get closed-form expression for integral
+            # with three q-coefficients (quartic q) from Mathematica without it being
+            # written with complex numbers, even though the answer is real.
             else:
                 raise ValueError(
                     f"This number of coefficients in the polynomial expansion of q not "
@@ -436,7 +381,7 @@ class CircularEquilibrium(Equilibrium):
         dr/dR = (R - R0) / sqrt((R - R0)**2 + Z**2)
         """
         R0 = self.user_options.R0
-        return (R - R0) / np.sqrt((R - R0) ** 2 + Z ** 2)
+        return (R - R0) / np.sqrt((R - R0) ** 2 + Z**2)
 
     def drdZ(self, R, Z):
         """
@@ -444,7 +389,7 @@ class CircularEquilibrium(Equilibrium):
         dr/dZ = Z / sqrt((R - R0)**2 + Z**2)
         """
         R0 = self.user_options.R0
-        return Z / np.sqrt((R - R0) ** 2 + Z ** 2)
+        return Z / np.sqrt((R - R0) ** 2 + Z**2)
 
     def dRdr(self, R, Z):
         """
@@ -522,8 +467,8 @@ class CircularEquilibrium(Equilibrium):
         R0 = self.user_options.R0
         r = self.r(R, Z)
         return (
-            self.d2psidr2_r(r) * (R - R0) ** 2 / ((R - R0) ** 2 + Z ** 2)
-            + self.dpsidr_r(r) * Z ** 2 / ((R - R0) ** 2 + Z ** 2) ** 1.5
+            self.d2psidr2_r(r) * (R - R0) ** 2 / ((R - R0) ** 2 + Z**2)
+            + self.dpsidr_r(r) * Z**2 / ((R - R0) ** 2 + Z**2) ** 1.5
         )
 
     def d2psidZ2(self, R, Z):
@@ -548,8 +493,8 @@ class CircularEquilibrium(Equilibrium):
         R0 = self.user_options.R0
         r = self.r(R, Z)
         return (
-            self.d2psidr2_r(r) * Z ** 2 / ((R - R0) ** 2 + Z ** 2)
-            + self.dpsidr_r(r) * (R - R0) ** 2 / ((R - R0) ** 2 + Z ** 2) ** 1.5
+            self.d2psidr2_r(r) * Z**2 / ((R - R0) ** 2 + Z**2)
+            + self.dpsidr_r(r) * (R - R0) ** 2 / ((R - R0) ** 2 + Z**2) ** 1.5
         )
 
     def d2psidRdZ(self, R, Z):
@@ -570,10 +515,10 @@ class CircularEquilibrium(Equilibrium):
         R0 = self.user_options.R0
         r = self.r(R, Z)
         return (
-            (self.d2psidr2_r(r) - self.dpsidr_r(r) / np.sqrt((R - R0) ** 2 + Z ** 2))
+            (self.d2psidr2_r(r) - self.dpsidr_r(r) / np.sqrt((R - R0) ** 2 + Z**2))
             * (R - R0)
             * Z
-            / ((R - R0) ** 2 + Z ** 2)
+            / ((R - R0) ** 2 + Z**2)
         )
 
     def fpol(self, psi):
