@@ -318,8 +318,6 @@ class TokamakEquilibrium(Equilibrium):
         wall=None,
         psi_axis_gfile=None,
         psi_bdry_gfile=None,
-        psi_axis=None,
-        psi_bdry=None,
         make_regions=True,
         settings=None,
         nonorthogonal_settings=None,
@@ -346,10 +344,10 @@ class TokamakEquilibrium(Equilibrium):
                The wall is closed, so the last point connects to the first.
         psi_axis_gfile = float
                The value of poloidal flux on the magnetic axis, given by the EFIT file.
-               psi_axis is the value calculated on the O-point.
+               self.psi_axis is the value calculated on the O-point.
         psi_bdry_gfile = float
                The value of poloidal flux at the plasma boundary, given by the EFIT file.
-               psi_bdry is the value calculated on the X-point.
+               self.psi_bdry is the value calculated on the X-point.
         make_regions = bool
                Generate the regions to be meshed. The default (True)
                means that the object is complete after initialisation.
@@ -459,7 +457,7 @@ class TokamakEquilibrium(Equilibrium):
                 and abs(self.psi_axis - psi_axis_gfile) > 1.0e-3
             ):
                 raise ValueError(
-                    f"psi_axis from the gfile ({psi_axis}) is different from psi "
+                    f"psi_axis from the gfile ({psi_axis_gfile}) is different from psi "
                     f"calculated on the O-point ({self.psi_axis})"
                 )
 
@@ -474,7 +472,7 @@ class TokamakEquilibrium(Equilibrium):
                 and abs(self.psi_bdry - psi_bdry_gfile) > 1.0e-3
             ):
                 raise ValueError(
-                    f"psi_bdry from the gfile ({psi_bdry}) is different from psi "
+                    f"psi_bdry from the gfile ({psi_bdry_gfile}) is different from psi "
                     f"calculated at the primary X-point ({self.psi_bdry})"
                 )
 
@@ -605,7 +603,7 @@ class TokamakEquilibrium(Equilibrium):
                 z = pos[1]
                 Br = self.Bp_R(r, z)
                 Bz = self.Bp_Z(r, z)
-                B = np.sqrt(Br ** 2 + Bz ** 2)
+                B = np.sqrt(Br**2 + Bz**2)
                 return [sign * Br / B, sign * Bz / B]
 
             pos = leg  # Starting position
@@ -1422,7 +1420,7 @@ class TokamakEquilibrium(Equilibrium):
 
                 # Smoother step function (Ken Perlin)
                 # https://en.wikipedia.org/wiki/Smoothstep
-                norm = 6.0 * norm ** 5 - 15.0 * norm ** 4 + 10.0 * norm ** 3
+                norm = 6.0 * norm**5 - 15.0 * norm**4 + 10.0 * norm**3
 
                 return norm * end_psi + (1.0 - norm) * start_psi
 
