@@ -6,9 +6,11 @@ GUI for Hypnotoad using Qt
 import ast
 import copy
 import func_timeout
+import gc
 import os
 import pathlib
 import textwrap
+import traceback
 import yaml
 
 from Qt.QtWidgets import (
@@ -142,6 +144,20 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
         self.options_form.itemDoubleClicked.connect(_table_item_edit_display)
         self.update_options_form()
 
+    def close(self):
+        # Delete and garbage-collect hypnotoad objects here so that any ParallelMap
+        # instances get deleted if they exists. ParallelMap.__del__() calls
+        # terminate on the worker processes. Needs to happen before program exits
+        # or program will hang waiting for parallel workers to finish (which they
+        # never do because they are waiting for another job in
+        # ParallelMap.worker_run()).
+        if hasattr(self, "eq"):
+            del self.eq
+        if hasattr(self, "mesh"):
+            del self.mesh
+        gc.collect()
+        super().close()
+
     def help_about(self):
         """About Hypnotoad"""
 
@@ -197,11 +213,11 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
 
         options_to_save = self.options
         if self.gui_options["save_full_yaml"]:
-            options_ = BoutMesh.user_options_factory.create(self.options)
-            options_.update(
-                tokamak.TokamakEquilibrium.user_options_factory.create(self.options)
+            mesh_options = BoutMesh.user_options_factory.create(self.options)
+            eq_options = tokamak.TokamakEquilibrium.user_options_factory.create(
+                self.options
             )
-            options_.update(
+            nonorth_options = (
                 tokamak.TokamakEquilibrium.nonorthogonal_options_factory.create(
                     self.options
                 )
@@ -211,10 +227,13 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
             # method of any numpy objects/types. Note this does return a scalar
             # and not a list for values that aren't arrays. Also remove any
             # private/magic keys
-            options_to_save = {
-                key: getattr(value, "tolist", lambda: value)()
-                for key, value in dict(options_).items()
-            }
+            options_to_save = {}
+            for key, value in mesh_options.items():
+                options_to_save[key] = getattr(value, "tolist", lambda: value)()
+            for key, value in eq_options.items():
+                options_to_save[key] = getattr(value, "tolist", lambda: value)()
+            for key, value in nonorth_options.items():
+                options_to_save[key] = getattr(value, "tolist", lambda: value)()
 
         with open(self.filename, "w") as f:
             yaml.dump(options_to_save, f)
@@ -281,7 +300,7 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
             return
 
         # Skip options handled specially elsewhere
-        del filtered_options["orthogonal"]
+        filtered_options.pop("orthogonal", None)
         del filtered_defaults["orthogonal"]
 
         self.options_form.setSortingEnabled(False)
@@ -353,7 +372,7 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
         self.options_file_line_edit.setText(filename)
         self.filename = filename
         self.read_options()
-        self.nonorthogonal_box.setChecked(not self.options["orthogonal"])
+        self.nonorthogonal_box.setChecked(not self.options.get("orthogonal", True))
 
     def read_options(self):
         """Read the options file"""
@@ -509,7 +528,12 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
         # Create all the geometrical quantities
         try:
             self.mesh.geometry()
-        except (ValueError, TypeError, func_timeout.FunctionTimedOut) as e:
+        except (
+            ValueError,
+            TypeError,
+            func_timeout.FunctionTimedOut,
+            SolutionError,
+        ) as e:
             self._popup_error_message(e)
             return
 
@@ -556,7 +580,9 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
             # no mesh, but do have equilibrium, so plot separatrices
             for region in self.eq.regions.values():
                 self.plot_widget.axes.plot(
-                    [p.R for p in region.points], [p.Z for p in region.points], "-o"
+                    [p.R for p in region.points],
+                    [p.Z for p in region.points],
+                    marker="o",
                 )
             self.plot_widget.axes.plot(*self.eq.x_points[0], "rx")
 
@@ -564,7 +590,7 @@ class HypnotoadGui(QMainWindow, Ui_Hypnotoad):
 
     def _popup_error_message(self, error):
         error_message = QErrorMessage()
-        error_message.showMessage(str(error))
+        error_message.showMessage(str(error) + "<br><br>" + traceback.format_exc())
         error_message.exec_()
 
 
