@@ -43,6 +43,7 @@ def main():
     if not args.noplot:
         from matplotlib import pyplot
 
+    import gc
     from ..cases.torpex import createMesh
 
     filename = args.filename
@@ -70,6 +71,9 @@ def main():
 
     mesh.writeGridfile(gridname)
 
+    del mesh
+    gc.collect()
+
 
 if __name__ == "__main__":
     main()
